==> CartMadeSimple0.1.0.zip: CartMadeSimple/action.save_admin_options.php <==
<?php
# Module: Cart Made Simple - An Order Intake module for CMS - CMS Made Simple
# Copyright (c) 2008 by Duketown <duketown@mantox.nl>
#
# This function allows the administrator to update the preferences
#
#-------------------------------------------------------------------------
# CMS - CMS Made Simple is (c) 2005 by Ted Kulp (wishy@cmsmadesimple.org)
# This project's homepage is: http://www.cmsmadesimple.org
# The module's homepage is: http://dev.cmsmadesimple.org/projects/cartms
#
#-------------------------------------------------------------------------
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
# Or read it online: http://www.gnu.org/licenses/licenses.html#GPL
#
#-------------------------------------------------------------------------

if (!isset($gCms)) exit;

if( !$this->CheckPermission( 'Modify Site Preferences' ) )
{
  return;
}

// Save the entered values and return
$this->SetPreference('cartcurrency', $params['cartcurrency']);
$this->SetPreference('numberformatdecimals', $params['numberformatdecimals']);
$this->SetPreference('numberformatdec_point', $params['numberformatdec_point']);
$this->SetPreference('numberformatthousand_sep', $params['numberformatthousand_sep']);
$this->SetPreference('mandatorystate', $params['mandatorystate']);
$this->SetPreference('admincost', $params['admincost']);
$this->SetPreference('admincostadd', $params['admincostadd']);
$this->SetPreference('admincostminamount', $params['admincostminamount']);
$this->SetPreference('contentthankyou', $params['contentthankyou']);

$params = array('tab_message'=> 'optionsupdated', 'active_tab' => 'cart');
$this->Redirect($id, 'defaultadmin', '', $params);
?>

==> CartMadeSimple0.1.1.zip: CartMadeSimple/action.save_admin_options.php <==
<?php
# Module: Cart Made Simple - An Order Intake module for CMS - CMS Made Simple
# Copyright (c) 2008 by Duketown <duketown@mantox.nl>
#
# This function allows the administrator to update the preferences
#
#-------------------------------------------------------------------------
# CMS - CMS Made Simple is (c) 2005 by Ted Kulp (wishy@cmsmadesimple.org)
# This project's homepage is: http://www.cmsmadesimple.org
# The module's homepage is: http://dev.cmsmadesimple.org/projects/cartms
#
#-------------------------------------------------------------------------
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
# Or read it online: http://www.gnu.org/licenses/licenses.html#GPL
#
#-------------------------------------------------------------------------

if (!isset($gCms)) exit;

if( !$this->CheckPermission( 'Modify Site Preferences' ) )
{
  return;
}

// Save the entered values and return
$this->SetPreference('cartcurrency', $params['cartcurrency']);
$this->SetPreference('numberformatdecimals', $params['numberformatdecimals']);
$this->SetPreference('numberformatdec_point', $params['numberformatdec_point']);
$this->SetPreference('numberformatthousand_sep', $params['numberformatthousand_sep']);
$this->SetPreference('mandatorystate', $params['mandatorystate']);
$this->SetPreference('admincost', $params['admincost']);
$this->SetPreference('admincostadd', $params['admincostadd']);
$this->SetPreference('admincostminamount', $params['admincostminamount']);
$this->SetPreference('contentthankyou', $params['contentthankyou']);
// Prepare fields to hold VAT rates
$this->SetPreference('vat0name', $params['vat0name']);
$this->SetPreference('vat1name', $params['vat1name']);
$this->SetPreference('vat2name', $params['vat2name']);
$this->SetPreference('vat3name', $params['vat3name']);
$this->SetPreference('vat4name', $params['vat4name']);
$this->SetPreference('vat0perc', $params['vat0perc']);
$this->SetPreference('vat1perc', $params['vat1perc']);
$this->SetPreference('vat2perc', $params['vat2perc']);
$this->SetPreference('vat3perc', $params['vat3perc']);
$this->SetPreference('vat4perc', $params['vat4perc']);

$params = array('tab_message'=> 'optionsupdated', 'active_tab' => 'cart');
$this->Redirect($id, 'defaultadmin', '', $params);
?>
